//---------------------------------------------------------------------------
#ifndef searchH
#define searchH
//---------------------------------------------------------------------------
#include <vcl\Classes.hpp>
#include <vcl\Controls.hpp>
#include <vcl\StdCtrls.hpp>
#include <vcl\Forms.hpp>
#include <vcl\ExtCtrls.hpp>
#include "mainfrm.h"
#include <swmgr.h>
//---------------------------------------------------------------------------
class TForm2 : public TForm
{
__published:	// IDE-managed Components
	TPanel *Panel1;
	TPanel *Panel2;
	TListBox *ListBox1;
	TPanel *Panel3;
	TMemo *SearchText;
	TPanel *plPreview;
	TRadioGroup *searchTypeGroup;
	TGroupBox *GroupBox1;
	TCheckBox *CheckBox2;
	TPanel *Panel4;
	TButton *Button1;
	void __fastcall Button1Click(TObject *Sender);
	void __fastcall ListBox1DblClick(TObject *Sender);
	void __fastcall ListBox1Click(TObject *Sender);
private:	// User declarations
	SWDispRTF *pvrtf;
public:		// User declarations
	ModMap::iterator target;
//	AnsiString CapText;

	__fastcall TForm2(TComponent* Owner);
};
//---------------------------------------------------------------------------
extern TForm2 *Form2;
//---------------------------------------------------------------------------
#endif
 